linkage: Calculate linkage values of variables and objects of a...

Description Usage Arguments Details Value Examples

Description

linkage() calculates a linkage value for every variable and every object of an input data.frame and returns a table with this information. This linkage value allows predictions about whether a variable/object can be used for multivariate analysis. If a variable/object is not well linked to the other entities, it will often appear as an outlier.

Usage

1

Arguments

matrix

data.frame with numeric values

Details

Structure of the resulting table:

column 1: linkage value (see code to understand how it's calculated)

column 2: logarithm of linkage value (useful for interpretation)

column 3: type (variable or object)

Value

table with linkage values

Examples

1
2
3
4
5
6
7
8
testmatrixrand <- data.frame(
   matrix(base::sample(0:1,400,replace=TRUE), nrow=20, ncol=20)
)

linkage(testmatrixrand)

link <- subset(linkage(testmatrixrand), type == "obj")
barplot(link$linkage, names.arg = rownames(link))

nevrome/varnastats documentation built on May 9, 2019, 10:43 a.m.