Description Usage Arguments Details Value Examples
linkage() calculates a linkage value for every variable and every object
of an input data.frame and returns a table with this information.
This linkage value allows predictions about whether a variable/object can be used
for multivariate analysis. If a variable/object is not well linked to the other entities,
it will often appear as an outlier.
1 |
matrix |
data.frame with numeric values |
Structure of the resulting table:
column 1: linkage value (see code to understand how it's calculated)
column 2: logarithm of linkage value (useful for interpretation)
column 3: type (variable or object)
table with linkage values
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.