Description Usage Arguments Value Examples
By comparison of significant correlations within variables and the variables the objects
incorporate predictvo() makes an prediction about the relation to given variables
for every object.
1 |
matrix |
data.frame with numeric values |
reltable |
table of correlation values (e.g. produced by |
mvars |
vector of variables of interest (full name) |
level |
switch to define if the prediction should be based on level 1 or on level 1 + level 2 variables. A level 1 variable is directly linked to a variable of interest, a level 2 variable is linked to the level 1 variables of said variable of interest 1: prediction is based only on level 1 variables. 2 (default): prediction is based on level 1 + level 2 variables. |
table with predicted, normalized relation values of every object and given
variables of interest. If no variable of interest has correlations to other variables,
predictvo() returns FALSE.
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.